# Changelog

## [0.0.15a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15a6) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15a5...0.0.15a6)

**Merged pull requests:**

- Update requirements.txt [\#165](https://github.com/OpenVoiceOS/OVOS-workshop/pull/165) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.15a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15a5) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15a4...0.0.15a5)

**Fixed bugs:**

- if it quacks like a duck... [\#164](https://github.com/OpenVoiceOS/OVOS-workshop/pull/164) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.15a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15a4) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15a3...0.0.15a4)

**Fixed bugs:**

- adapt backwards compat via metaclass [\#163](https://github.com/OpenVoiceOS/OVOS-workshop/pull/163) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.15a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15a3) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15a2...0.0.15a3)

**Fixed bugs:**

- adapt backwards compat [\#162](https://github.com/OpenVoiceOS/OVOS-workshop/pull/162) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.15a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15a2) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15a1...0.0.15a2)

**Fixed bugs:**

- fix skill\_directories [\#161](https://github.com/OpenVoiceOS/OVOS-workshop/pull/161) ([JarbasAl](https://github.com/JarbasAl))

**Closed issues:**

- `NameError: name '_get_skill_dirs' is not defined.` [\#159](https://github.com/OpenVoiceOS/OVOS-workshop/issues/159)

## [0.0.15a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15a1) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.14...0.0.15a1)

**Fixed bugs:**

- update imports [\#160](https://github.com/OpenVoiceOS/OVOS-workshop/pull/160) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
